@@ -518,7 +518,9 @@ def merge_tree(src, dst, symlinks=False, timeout=90, lock=None, locking=True, cl
     dst = os.path.normpath(os.path.normcase(dst))
     src = os.path.normpath(os.path.normcase(src))
     assert not dst.startswith(src), ("Can't merge/copy source into subdirectory of itself.  "
-                                     "Please create separate spaces for these things.")
+                                     "Please create separate spaces for these things.\n"
+                                     "  src: {0}\n"
+                                     "  dst: {1}".format(src, dst))
 
     new_files = copytree(src, dst, symlinks=symlinks, dry_run=True)
     existing = [f for f in new_files if isfile(f)]
@@ -1556,6 +1558,8 @@ def insert_variant_versions(requirements_dict, variant, env):
             for i, x in enumerate(matches):
                 if x and (env in ('build', 'host') or x.group(1) in build_deps):
                     del reqs[i]
+                    if not isinstance(val, string_types):
+                        val = val[0]
                     reqs.insert(i, ensure_valid_spec(' '.join((x.group(1), val))))
 
     xx_re = re.compile("([0-9a-zA-Z\.\-\_]+)\s+x\.x")
