@@ -29,7 +29,7 @@ DEFAULT_VARIANTS = {
     'cpu_optimization_target': 'nocona',
     'pin_run_as_build': OrderedDict(python=OrderedDict(min_pin='x.x', max_pin='x.x')),
     'ignore_version': [],
-    'ignore_build_only_deps': ['python'],
+    'ignore_build_only_deps': ['python', 'numpy'],
     'extend_keys': ['pin_run_as_build', 'ignore_version', 'ignore_build_only_deps'],
     'cran_mirror': "https://cran.r-project.org",
 }
